miml.classifier.mimlTOmi package — miml documentation

Skip to main content
`Ctrl`+`K`

# miml.classifier.mimlTOmi package

## Submodules

- `MIMLtoMIBRClassifier`
  - `MIMLtoMIBRClassifier.fit_internal()`
  - `MIMLtoMIBRClassifier.predict()`
  - `MIMLtoMIBRClassifier.predict_proba()`
- `MIMLtoMIClassifier`
  - `MIMLtoMIClassifier.evaluate()`
  - `MIMLtoMIClassifier.fit_internal()`
  - `MIMLtoMIClassifier.predict()`
  - `MIMLtoMIClassifier.predict_bag()`
  - `MIMLtoMIClassifier.predict_proba()`
- `MIMLtoMILPClassifier`
  - `MIMLtoMILPClassifier.fit_internal()`
  - `MIMLtoMILPClassifier.predict()`
  - `MIMLtoMILPClassifier.predict_proba()`